==> haskell-persistent-2.14.5.1-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-L1AtPiKbtFwKgjvmzS74Hn
key:                  persistent-2.14.5.1-L1AtPiKbtFwKgjvmzS74Hn
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  7d0a11b1b0cd788d750a86e32502ee73
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-L1AtPiKbtFwKgjvmzS74Hn
depends:
    aeson-2.1.2.1-nFo3VMHABFBaVDPPKfnuT
    attoparsec-0.14.4-53YjHEyIcZv40S6MstOLSz base-4.17.2.1
    base64-bytestring-1.2.1.0-B2irD5s7HHEKJGrPbG6ke5
    blaze-html-0.9.2.0-Af5P3A2URAm8PEOIhy6b3k bytestring-0.11.5.3
    conduit-1.3.6.1-BrVAMLporIm8aoMwut0RwH containers-0.6.7
    deepseq-1.4.8.0 fast-logger-3.2.3-43J6juoTNIo1lHxPhVo33u
    http-api-data-0.5.1-AHTnyCFXOYVF8KyrjnTYIM
    lift-type-0.1.2.0-3WduLmUQD7GF882uE41K8L
    monad-logger-0.3.42-Efmn895WJv5KhxWegXtIHB mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    resource-pool-0.2.3.2-AfoOpxuuUNHQYc8kOiu0U
    resourcet-1.2.6-EDu2BuTIWaf4YhdsfzLxLM
    scientific-0.3.7.0-H4Og6N92k1lGQSMIPZo0fR
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-P0ISBryUMCLQnt15KL0p9
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-CSkQ6WBjw9j80OvsxjG0yH
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB
    vault-0.3.1.5-3XWVSL1dXSOKbbStgdcwIr
    vector-0.13.2.0-5IsJnyR8rmEEUPyguFia6U

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.14.5.1-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-H6AbY5StPE22gi3IRf8e7i
key:                  persistent-2.14.5.1-H6AbY5StPE22gi3IRf8e7i
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  9251f3b915135bb2b4a5ddf5c2273b99
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-H6AbY5StPE22gi3IRf8e7i
depends:
    aeson-2.1.2.1-4cRYi3WcVwTKRqMhXUztfB
    attoparsec-0.14.4-CvEJsUQt6CCDts1bkyqJXU base-4.17.2.1
    base64-bytestring-1.2.1.0-3dKpuH5HS82KwnSpVDBu71
    blaze-html-0.9.2.0-3YZTlMAnllRFVmykcDevNv bytestring-0.11.5.3
    conduit-1.3.6.1-KZNeLPeXvjD5EEhRbg4Ht8 containers-0.6.7
    deepseq-1.4.8.0 fast-logger-3.2.3-2PLNu4khW917eOxjQFwyeS
    http-api-data-0.5.1-3Hz7miSr6ieAxSH24bqe3c
    lift-type-0.1.2.0-91wdTy5wnT59C205avSSUz
    monad-logger-0.3.42-1wtDzALk7EUKZtCAVFSfJI mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    resource-pool-0.2.3.2-CFkp9ucE6Sr75eiiQGnxJ3
    resourcet-1.2.6-4s6buasN4G4AuwCuvXVHSL
    scientific-0.3.7.0-K2KPplW6Nka7Ws1cS3R2Yx
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-6i65Sr2FVp53pAKeRcKAmJ
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-LoveZ8ajQHRGyZYXvS1EQ2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-A2tjqfQXDXnFd3Ae9FP0C3
    vault-0.3.1.5-9RRuhN1k9usHHNlYjYVyhC
    vector-0.13.2.0-5H8NMvQc0Ab8bNH9ZMgAUW

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
